@@ -1,7 +1,6 @@
 from ipaddress import IPv4Address, IPv4Network
 from random import Random
 from string import ascii_letters, ascii_uppercase, digits, hexdigits
-from typing import Tuple
 from uuid import UUID
 
 from .data_source import load_builds_list, load_devices_list
@@ -63,9 +62,7 @@ class RandomDeviceInfoGenerator:
         random = Random(self.seed)
         return ":".join(self.rand_str(random, hexdigits, 2) for _ in range(6)).upper()
 
-    def ip_address(
-        self, network: IPv4Network = IPv4Network("188.0.0.0/8")
-    ) -> Tuple[int, int, int, int]:
+    def ip_address(self, network: IPv4Network = IPv4Network("188.0.0.0/8")):
         random = Random(self.seed)
 
         address = IPv4Address(
@@ -74,7 +71,7 @@ class RandomDeviceInfoGenerator:
                 int(network.broadcast_address),
             )
         )
-        return tuple(int(i) for i in str(address).split("."))
+        return [int(i) for i in str(address).split(".")]
 
     def incremental(self):
         random = Random(self.seed)
